# Movable Type plugin.
#
# Release 0.01 (Jan 10, 2008) initial version.
#
# Copyright (c) 2004-2008 Yujiro Araki

package MT::Plugin::DefaultValueSetter;
use strict;
use MT;
use base qw(MT::Plugin);

our $VERSION = '0.01';
our $overwrite = '0';

my $plugin = MT::Plugin::DefaultValueSetter->new({
    name => 'DefaultValueSetter',
    description => 'Set default value for entry.',
    doc_link => 'http://www.koikikukan.com/archives/2007/01/10-010101.php',
    author_name => 'Yujiro Araki',
    author_link => 'http://www.koikikukan.com/',
    version => $VERSION,
    blog_config_template => 'config.tmpl',
    settings => new MT::PluginSettings([
        ['def_entry_title'],
        ['def_entry_content'],
        ['def_entry_more'],
        ['def_entry_tags'],
        ['def_entry_excerpt'],
        ['def_entry_keywords'],
    ]),
    l10n_class => 'DefaultValueSetter::L10N',
});
MT->add_plugin($plugin);

sub init_registry {
    my $plugin = shift;
    $plugin->registry({
        callbacks => {
            'MT::App::CMS::template_source.edit_entry'
                => \&set_default_value,
            'MT::App::CMS::template_source.archetype_editor'
                => \&set_default_value_content,
        },
   });
}

sub set_default_value {
    my ($cb, $app, $template) = @_;

    my $blog_id = $app->blog->id;
    my $config = config('blog:' . $blog_id);
    my $entry_id = $app->param('id');

    my $title = $config->{def_entry_title};
    if ($entry_id eq '' && $title ne '') {
        my $old = <<HERE;
<input name="title" id="title" tabindex="1" value="<\$mt:var name="title" escape="html"\$>" maxlength="255" mt:watch-change="1" onkeyup="rebasename(this)" />
HERE
        $old = quotemeta($old);
        my $new = <<HERE;
<input name="title" id="title" tabindex="1" value="$title" maxlength="255" mt:watch-change="1" onkeyup="rebasename(this)" />
HERE
        $$template =~ s/$old/$new/;
    }

    my $excerpt = $config->{def_entry_excerpt};
    if ($entry_id eq '' && $excerpt ne '') {
        my $old = <<HERE;
<textarea name="excerpt" id="excerpt" class="full-width short" tabindex="7" cols="" rows="" mt:watch-change="1"><\$mt:var name="excerpt" escape="html"\$></textarea>
HERE
        $old = quotemeta($old);
        my $new = <<HERE;
<textarea name="excerpt" id="excerpt" class="full-width short" tabindex="7" cols="" rows="" mt:watch-change="1">$excerpt</textarea>
HERE
        $$template =~ s/$old/$new/;
    }

    my $keywords = $config->{def_entry_keywords};
    if ($entry_id eq '' && $keywords ne '') {
        my $old = <<HERE;
<input name="keywords" id="keywords" class="full-width" tabindex="8" value="<\$mt:var name="keywords" escape="html"\$>" mt:watch-change="1" autocomplete="off" />
HERE
        $old = quotemeta($old);
        my $new = <<HERE;
<input name="keywords" id="keywords" class="full-width" tabindex="8" value="$keywords" mt:watch-change="1" autocomplete="off" />
HERE
        $$template =~ s/$old/$new/;
    }

    my $tags = $config->{def_entry_tags};
    if ($entry_id eq '' && $tags ne '') {
        my $old = <<HERE;
<input name="tags" id="tags" class="full-width" tabindex="5" value="<\$mt:var name="tags" escape="html"\$>" mt:watch-change="1" autocomplete="off" />
HERE
        $old = quotemeta($old);
        my $new = <<HERE;
<input name="tags" id="tags" class="full-width" tabindex="5" value="$tags" mt:watch-change="1" autocomplete="off" />
HERE
        $$template =~ s/$old/$new/;
    }
}

sub set_default_value_content {
    my ($cb, $app, $template) = @_;

    my $blog_id = $app->blog->id;
    my $config = config('blog:' . $blog_id);
    my $entry_id = $app->param('id');

    my $content = $config->{def_entry_content};
    if ($entry_id eq '' && $content ne '') {
        my $old = <<HERE;
<input type="hidden" id="editor-input-content" name="text" value="<\$mt:var name="text" escape="html"\$>" />
HERE
        $old = quotemeta($old);
        my $new = <<HERE;
<input type="hidden" id="editor-input-content" name="text" value="$content" />
HERE
        $$template =~ s/$old/$new/;
    }

    my $more = $config->{def_entry_more};
    if ($entry_id eq '' && $more ne '') {
        my $old = <<HERE;
<input type="hidden" id="editor-input-extended" name="text_more" value="<\$mt:var name="text_more" escape="html"\$>" />
HERE
        $old = quotemeta($old);
        my $new = <<HERE;
<input type="hidden" id="editor-input-extended" name="text_more" value="$more" />
HERE
        $$template =~ s/$old/$new/;
    }
}

sub config {
    my $config = {};
    return $config unless $plugin;
    require MT::Request;
    my $scope = shift || 'system';
    $config = MT::Request->instance->cache('defaultvaluesetter_config_'.$scope);
    if (!$config) {
        $config = $plugin->get_config_hash($scope);
        MT::Request->instance->cache('defaultvaluesetter_config_'.$scope, $config);
    }
    $config;
}

1;
